@@ -1,23 +1,19 @@
-import typing
-
-from function2widgets.widgets.codeeditor import (
-    UniversalSourceCodeEditor,
-    JsonEditor,
-    ListEditor,
-    TupleEditor,
-    DictEditor,
-)
-from function2widgets.widgets.lineedit import LineEdit, IntLineEdit, FloatLineEdit
-from function2widgets.widgets.textedit import PlainTextEdit, SourceCodeEdit
+from function2widgets.widgets.editor.codeeditor import CodeEditor
+from function2widgets.widgets.editor.dicteditor import DictEditor
+from function2widgets.widgets.lineedit import IntLineEdit, FloatLineEdit, LineEdit
+from function2widgets.widgets.editor.jsoneditor import JsonEditor
+from function2widgets.widgets.editor.listeditor import ListEditor
+from function2widgets.widgets.numberinput import IntSpinBox, FloatSpinBox, Dial, Slider
+from function2widgets.widgets.pathedit import PathEdit, FilePathEdit, DirPathEdit
+from function2widgets.widgets.selectwidget.combobox import ComboBox
 from function2widgets.widgets.selectwidget import (
-    ComboBox,
     ComboBoxEdit,
     RadioButtonGroup,
     CheckBoxGroup,
     CheckBox,
 )
-from function2widgets.widgets.numberedit import IntSpinBox, FloatSpinBox, Dial, Slider
-from function2widgets.widgets.pathedit import PathEdit, FilePathEdit, DirPathEdit
+from function2widgets.widgets.textedit import PlainTextEdit, CodeEdit
+from function2widgets.widgets.editor.tupleeditor import TupleEditor
 
 BASIC_PARAMETER_WIDGETS = {
     LineEdit.__name__: LineEdit,
@@ -27,8 +23,8 @@ BASIC_PARAMETER_WIDGETS = {
     FilePathEdit.__name__: FilePathEdit,
     DirPathEdit.__name__: DirPathEdit,
     PlainTextEdit.__name__: PlainTextEdit,
-    SourceCodeEdit.__name__: SourceCodeEdit,
-    UniversalSourceCodeEditor.__name__: UniversalSourceCodeEditor,
+    CodeEdit.__name__: CodeEdit,
+    CodeEditor.__name__: CodeEditor,
     JsonEditor.__name__: JsonEditor,
     DictEditor.__name__: DictEditor,
     ListEditor.__name__: ListEditor,
